@@ -34,9 +34,10 @@ void lw_about(void){
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
     vbox = gtk_vbox_new (FALSE, 5);
-    label_about = gtk_label_new (_("Live Wallpaper\n Version 0.2 \n Copyright(c) 2010\n \
+    label_about = gtk_label_new (_("Live Wallpaper\n Version 0.4 \n Copyright(c) 2010\n \
 Tanya Makova\n Vlad Vasiliev\n \
-Copyright(c) 2010 for design \n Vasya Bobrikov")); 
+Copyright(c) 2010 for design themes Berlin and Modern Vasya Bobrikov\n \
+Copyright(c) 2010 for design theme Matrix Andrew Zhilin")); 
     gtk_box_pack_start (GTK_BOX (vbox), label_about, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window)->vbox),
                                    vbox, TRUE, TRUE, 0);
@@ -56,6 +57,7 @@ create_theme_selector (void)
 
       hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Berlin"));
       hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Modern"));
+      hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("Matrix"));
       return selector;
 }
 /*******************************************************************************/
@@ -79,6 +81,10 @@ create_themes_button (gchar *theme){
             hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 1);
             hildon_button_set_value(HILDON_BUTTON(button), _("Modern"));
         }
+        if (!strcmp(theme, "Matrix")){
+            hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, 2);
+            hildon_button_set_value(HILDON_BUTTON(button), _("Matrix"));
+        }
 
     }
     return button;
@@ -95,9 +101,14 @@ create_rich_animation_button (gboolean active)
     return button;
 }
 
+/*******************************************************************************/
+void
+show_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv){
+    lw_settings(priv, NULL);
+}
 /*******************************************************************************/
 void 
-lw_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv){
+lw_settings(Animation_WallpaperPrivate *priv, gpointer data){
     gint result;
     GtkWidget *window = NULL;
     GtkWidget *save_button;
@@ -105,6 +116,7 @@ lw_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv){
     GtkWidget *rich_animation_button;
 
     window = gtk_dialog_new();
+
     gtk_window_set_title(GTK_WINDOW(window), _("Live Wallpaper Settings"));
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
@@ -132,13 +144,18 @@ lw_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv){
                     priv->theme = g_strdup("Berlin");
                 if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Modern")))
                     priv->theme = g_strdup("Modern");
+                if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Matrix")))
+                    priv->theme = g_strdup("Matrix");
                 if (hildon_check_button_get_active (rich_animation_button))
                     priv->rich_animation = TRUE;
                 else
                     priv->rich_animation = FALSE;
             }
             save_config(priv);
-            reload_scene(priv->desktop_plugin);
+            send_dbus_signal (priv,
+                              LIVEWP_SIGNAL_INTERFACE,
+                              LIVEWP_SIGNAL_PATH,
+                              LIVEWP_RELOAD_CONFIG);
         break;
         default:
         case GTK_RESPONSE_OK:
@@ -152,3 +169,4 @@ lw_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv){
     if (window)
         gtk_widget_destroy(window);
 }
+
